@@ -3,6 +3,8 @@ from requests.auth import HTTPBasicAuth
 
 from xray.system import XraySystem
 from xray.components import XrayComponents
+from xray.summary import XraySummary
+from xray.issues import XrayIssues
 
 
 class XrayRestClient(object):
@@ -18,3 +20,11 @@ class XrayRestClient(object):
     @property
     def components(self):
         return XrayComponents(base_url=self.base_url, session=self._session)
+
+    @property
+    def summary(self):
+        return XraySummary(base_url=self.base_url, session=self._session)
+
+    @property
+    def issues(self):
+        return XrayIssues(base_url=self.base_url, session=self._session)
